==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/entity/task/TaskMelon.java <==
package com.github.tartaricacid.touhoulittlemaid.entity.task;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.api.task.IFarmTask;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.google.common.base.Predicates;
import com.mojang.datafixers.util.Pair;
import java.util.Collections;
import java.util.List;
import java.util.function.Predicate;
import net.minecraft.class_1304;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1893;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_5455;

import static com.github.tartaricacid.touhoulittlemaid.datagen.EnchantmentKeys.getEnchantmentLevel;

public class TaskMelon implements IFarmTask {
    public static final class_2960 UID = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "melon");

    @Override
    public class_2960 getUid() {
        return UID;
    }

    @Override
    public class_1799 getIcon() {
        return class_1802.field_8497.method_7854();
    }

    @Override
    public boolean isSeed(class_1799 stack) {
        return false;
    }

    @Override
    public boolean canHarvest(EntityMaid maid, class_2338 cropPos, class_2680 cropState) {
        class_2248 block = cropState.method_26204();
        if (block == class_2246.field_46283 || block == class_2246.field_46282) {
            class_2248 stem = block == class_2246.field_46283 ? class_2246.field_46285 : class_2246.field_46284;
            for (class_2350 direction : class_2350.class_2353.field_11062) {
                class_2680 offsetState = maid.field_6002.method_8320(cropPos.method_10093(direction));
                if (offsetState.method_27852(stem)) {
                    return true;
                }
            }
        }
        return false;
    }

    @Override
    public void harvest(EntityMaid maid, class_2338 cropPos, class_2680 cropState) {
        class_1799 mainHandItem = maid.method_6047();
        class_5455 access = maid.field_6002.method_30349();
        if (cropState.method_27852(class_2246.field_46283) && getEnchantmentLevel(access, class_1893.field_9099, mainHandItem) > 0) {
            if (maid.destroyBlock(cropPos, false)) {
                mainHandItem.method_7970(1, maid, class_1304.field_6173);
                class_2248.method_9577(maid.field_6002, cropPos, class_1802.field_17522.method_7854());
            }
        } else {
            maid.destroyBlock(cropPos);
        }
    }

    @Override
    public boolean canPlant(EntityMaid maid, class_2338 basePos, class_2680 baseState, class_1799 seed) {
        return false;
    }

    @Override
    public class_1799 plant(EntityMaid maid, class_2338 basePos, class_2680 baseState, class_1799 seed) {
        return seed;
    }

    @Override
    public double getCloseEnoughDist() {
        return 1.5;
    }

    @Override
    public List<Pair<String, Predicate<EntityMaid>>> getConditionDescription(EntityMaid maid) {
        return Collections.singletonList(Pair.of("has_silk_touch", Predicates.alwaysTrue()));
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.7.3-neo1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/entity/task/TaskMelon.java <==
package com.github.tartaricacid.touhoulittlemaid.entity.task;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.api.task.IFarmTask;
import com.github.tartaricacid.touhoulittlemaid.entity.ai.brain.task.MaidFarmPlantTask;
import com.github.tartaricacid.touhoulittlemaid.entity.ai.brain.task.MaidFarmSurroundingMoveTask;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.google.common.base.Predicates;
import com.google.common.collect.Lists;
import com.mojang.datafixers.util.Pair;
import java.util.Collections;
import java.util.List;
import java.util.function.Predicate;
import net.minecraft.class_1304;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1893;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_2960;
import net.minecraft.class_5455;
import net.minecraft.class_7893;

import static com.github.tartaricacid.touhoulittlemaid.datagen.EnchantmentKeys.getEnchantmentLevel;

public class TaskMelon implements IFarmTask {
    public static final class_2960 UID = class_2960.method_60655(TouhouLittleMaid.MOD_ID, "melon");

    @Override
    public class_2960 getUid() {
        return UID;
    }

    @Override
    public class_1799 getIcon() {
        return class_1802.field_8497.method_7854();
    }

    @Override
    public boolean isSeed(class_1799 stack) {
        return false;
    }

    @Override
    public List<Pair<Integer, class_7893<? super EntityMaid>>> createBrainTasks(EntityMaid maid) {
        MaidFarmSurroundingMoveTask maidFarmSurroundingMoveTask = new MaidFarmSurroundingMoveTask(this, 0.6f);
        MaidFarmPlantTask maidFarmPlantTask = new MaidFarmPlantTask(this);
        return Lists.newArrayList(Pair.of(5, maidFarmSurroundingMoveTask), Pair.of(6, maidFarmPlantTask));
    }

    @Override
    public boolean canHarvest(EntityMaid maid, class_2338 cropPos, class_2680 cropState) {
        class_2248 block = cropState.method_26204();
        if (block == class_2246.field_46283 || block == class_2246.field_46282) {
            class_2248 stem = block == class_2246.field_46283 ? class_2246.field_46285 : class_2246.field_46284;
            for (class_2350 direction : class_2350.class_2353.field_11062) {
                class_2680 offsetState = maid.field_6002.method_8320(cropPos.method_10093(direction));
                if (offsetState.method_27852(stem)) {
                    return true;
                }
            }
        }
        return false;
    }

    @Override
    public void harvest(EntityMaid maid, class_2338 cropPos, class_2680 cropState) {
        class_1799 mainHandItem = maid.method_6047();
        class_5455 access = maid.field_6002.method_30349();
        if (cropState.method_27852(class_2246.field_46283) && getEnchantmentLevel(access, class_1893.field_9099, mainHandItem) > 0) {
            if (maid.destroyBlock(cropPos, false)) {
                mainHandItem.method_7970(1, maid, class_1304.field_6173);
                class_2248.method_9577(maid.field_6002, cropPos, class_1802.field_17522.method_7854());
            }
        } else {
            maid.destroyBlock(cropPos);
        }
    }

    @Override
    public boolean canPlant(EntityMaid maid, class_2338 basePos, class_2680 baseState, class_1799 seed) {
        return false;
    }

    @Override
    public class_1799 plant(EntityMaid maid, class_2338 basePos, class_2680 baseState, class_1799 seed) {
        return seed;
    }

    @Override
    public double getCloseEnoughDist() {
        return 1.5;
    }

    @Override
    public List<Pair<String, Predicate<EntityMaid>>> getConditionDescription(EntityMaid maid) {
        return Collections.singletonList(Pair.of("has_silk_touch", Predicates.alwaysTrue()));
    }
}
